@@ -20,7 +20,6 @@
 #include "toolcontext.h"
 #include "lvmcache.h"
 #include "archiver.h"
-#include "lvmlockd.h"
 
 struct volume_group *alloc_vg(const char *pool_name, struct cmd_context *cmd,
 			      const char *vg_name)
@@ -99,7 +98,7 @@ void release_vg(struct volume_group *vg)
 	    !lvmcache_vginfo_holders_dec_and_test_for_zero(vg->vginfo))
 		return;
 
-	release_vg(vg->vg_ondisk);
+	release_vg(vg->vg_committed);
 	release_vg(vg->vg_precommitted);
 	if (vg->cft_precommitted)
 		dm_config_destroy(vg->cft_precommitted);
