@@ -97,17 +97,25 @@ static const char * const _blacklist_maps[] = {
 	"locale/locale-archive",
 	"/LC_MESSAGES/",
 	"gconv/gconv-modules.cache",
+	"/ld-2.",		/* not using dlopen,dlsym during mlock */
+	"/libattr.so.",		/* not using during mlock (udev) */
 	"/libblkid.so.",	/* not using lzma during mlock (selinux) */
+	"/libbz2.so.",		/* not using during mlock (udev) */
+	"/libcap.so.",		/* not using during mlock (udev) */
+	"/libdw-",		/* not using during mlock (udev) */
+	"/libelf-",		/* not using during mlock (udev) */
 	"/liblzma.so.",	/* not using lzma during mlock (selinux) */
 	"/libncurses.so.",	/* not using ncurses during mlock */
 	"/libpcre.so.",	/* not using pcre during mlock (selinux) */
 	"/libreadline.so.",	/* not using readline during mlock */
+	"/libresolv-",	/* not using during mlock (udev) */
 	"/libselinux.so.",	/* not using selinux during mlock */
 	"/libsepol.so.",	/* not using sepol during mlock */
 	"/libtinfo.so.",	/* not using tinfo during mlock */
 	"/libudev.so.",		/* not using udev during mlock */
 	"/libuuid.so.",		/* not using uuid during mlock (blkid) */
 	"/libdl-",		/* not using dlopen,dlsym during mlock */
+	"/libz.so.",		/* not using during mlock (udev) */
 	"/etc/selinux",		/* not using selinux during mlock */
 	/* "/libdevmapper-event.so" */
 };
@@ -638,3 +646,8 @@ void memlock_unlock(struct cmd_context *cmd)
 }
 
 #endif
+
+int memlock_count_daemon(void)
+{
+	return _memlock_count_daemon;
+}
